@@ -25,6 +25,7 @@ const char *ripe_servers[] = {
     "whois.nic.ir",
     "whois.nic.ck",
     "whois.ra.net",
+    "whois.radb.net",
     NULL
 };
 
@@ -35,6 +36,7 @@ const char *hide_strings[] = {
     "NOTICE: Access to .INFO WHOIS", "",
     "NOTICE: Access to the .aero", "",
     "This Registry database contains ONLY .EDU", "type: help",	/* edu */
+    "% .eu Whois Server", "% of the database",
     "The data in Register", "",				    /* Register.Com */
     "The Data in the Tucows", "RECORD DOES NOT",
     " The data contained in the WHOIS", "",			/* DOTSTER */
@@ -56,6 +58,8 @@ const char *hide_strings[] = {
     "Interdomain's WHOIS", "DOES NOT SIGNIFY",
     "The Data provided by Stargate Holdings", "(2) enable any",
     "; This data is provided by domaindiscount24.com", "",
+    "%% BookMyName Whois", "%% this policy",
+    "The .coop registry WHOIS", "VERIFICATION, NOR DO",
     NULL, NULL
 };
 
